function [Lfiltered,Dfiltered,Mfiltered] = thro070(thro,flap)
%-------------------------------------------------------------------------%
% thro: the throttle of propeller
% | thro = 0: no propeller
% | thro = 1: 70% propeller

% flap: the deflection
% | flap = 0: 0% flap
% | flap = 1: 50% flap down
% | flap = 2: 50% flap up
% | flap = 3: 100% flap down
% | flap = 4: 100% flap up

% example: [Lf,Df,Mf] = datafilter(0,1);
%-------------------------------------------------------------------------%
ni = nargin;
no = nargout;

if ni < 2
    error('Insufficient input')
end

switch thro
    case 0
        str1 = 'no propeller';
        switch flap
            case 0
                dataset = '0thro0flap';
                str2 = '0% flap';
                count= 0;
            case 1
                dataset = '0thro50flapdown';
                str2 = '50% flap down';
                count= 1;
            case 2
                dataset = '0thro50flapup';
                str2 = '50% flap up';
                count= 2;
            case 3
                dataset = '0thro100flapdown';
                str2 = '100% flap down';
                count= 3;
            case 4
                dataset = '0thro100flapup';
                str2 = '100% flap up';
                count= 4;
            otherwise
                error('Index of the flap is incorrect.');
        end
    case 1
        str1 = '70% propeller';
        count= 5;
        switch flap
            case 0
                dataset = '70thro0flap';
                str2 = '0% flap';
            case 1
                dataset = '70thro50flapdown';
                str2 = '50% flap down';
            case 2
                dataset = '70thro50flapup';
                str2 = '50% flap up';
            case 3
                dataset = '70thro100flapdown';
                str2 = '100% flap down';
            case 4
                dataset = '70thro100flapup';
                str2 = '100% flap up';
            otherwise
                error('Index of the flap is incorrect.');
        end
    otherwise
        error('Index of the throttle is wrong.')
end

fileID = fopen([ dataset '.txt']);
average = textscan(fileID,'%f %f %f %f %f %f %f %f %f %f %f %f %f %f');
fclose(fileID);

ta = average{1,1}; 
Fa(:,1) = average{1,2};
Fa(:,2) = average{1,3};
Fa(:,3) = average{1,4};
Ma(:,1) = average{1,5};
Ma(:,2) = average{1,6};
Ma(:,3) = average{1,7};
rpm = average{1,8};
temp1 = average{1,9};
p = average{1,10};
dp = average{1,11};
v = average{1,12};
q = average{1,13};
alpha = average{1,14};
% arad = deg2rad(alpha);
A = 1 * 0.225; % One wing with winglet
c = 0.225;     % wing chord
p0=101325;%standard aeropheric pressure
tempK = temp1 + 273.15; % Degree Kelvin
rho = 1.293.*(p./p0).*(273.15./tempK);

Fax = myfilter(Fa(:,1));
Fay = myfilter(Fa(:,2));
Faz = myfilter(Fa(:,3));

Max = myfilter(Ma(:,1));
May = myfilter(Ma(:,2));
Maz = myfilter(Ma(:,3));

switch count %calculte the offset when airspeed is almost but not zero for 0 throttle
    case 0
        [offset1,offset2,offset3,offset4,offset5,offset6] = offset(1,121,Fa,Ma);
    case 1
        [offset1,offset2,offset3,offset4,offset5,offset6] = offset(1,51,Fa,Ma);
    case 2
        [offset1,offset2,offset3,offset4,offset5,offset6] = offset(71,184,Fa,Ma);
    case 3
        [offset1,offset2,offset3,offset4,offset5,offset6] = offset(70,147,Fa,Ma);
    case 4
        [offset1,offset2,offset3,offset4,offset5,offset6] = offset(118,141,Fa,Ma);
    case 5
        offset1=0;
        offset2=0;
        offset3=0;
        offset4=0;
        offset5=0;
        offset6=0;    
end

load('calithro70.mat');
alphai=-180:0.1:180;
alphai=alphai';
Mac1=myfilter(Mac1);
Fac1=myfilter(Fac1);
Mac2=myfilter(Mac2);
Fac2=myfilter(Fac2);
Mac3=myfilter(Mac3);
Fac3=myfilter(Fac3);
Mac1 = interp1(alpha0,Mac1,alphai,'nearest');% for difference calculation, alpha needs to be consistent for differenct measurements
Fac1 = interp1(alpha0,Fac1,alphai,'nearest');
Mac2 = interp1(alpha0,Mac2,alphai,'nearest');
Fac2 = interp1(alpha0,Fac2,alphai,'nearest');
Mac3 = interp1(alpha0,Mac3,alphai,'nearest');
Fac3 = interp1(alpha0,Fac3,alphai,'nearest');
%-----------------------v=6---------------------------------%
alpha1 = alpha(v>5&v<6);
v1 = v(v>5&v<6);
rho1 = rho(v>5&v<6);
Fax1 = Fax(v>5&v<6);
Max1 = Max(v>5&v<6);
Fay1 = Fay(v>5&v<6);
May1 = May(v>5&v<6);
Faz1 = Faz(v>5&v<6);
Maz1 = Maz(v>5&v<6);
[alpha1, ialpha1, ~] = unique(alpha1); %from -180 to 180
v1 = v1(ialpha1);
rho1 = rho1(ialpha1);
Fax1 = Fax1(ialpha1);
Max1 = Max1(ialpha1);
Fay1 = Fay1(ialpha1);
May1 = May1(ialpha1);
Faz1 = Faz1(ialpha1);
Maz1 = Maz1(ialpha1);
vf1 = interp1(alpha1,v1,alphai,'nearest');
rhof1 = interp1(alpha1,rho1,alphai,'nearest');
Faxf1 = interp1(alpha1,Fax1,alphai,'nearest');
Fayf1 = interp1(alpha1,Fay1,alphai,'nearest');
Fazf1 = interp1(alpha1,Faz1,alphai,'nearest');


Maxf1 = interp1(alpha1,Max1,alphai,'nearest');
Mayf1 = interp1(alpha1,May1,alphai,'nearest');
Mazf1 = interp1(alpha1,Maz1,alphai,'nearest');

Fxf1 = Faxf1-Fac1-offset1;
Fyf1 = Fayf1-Fac2-offset2;
Fzf1 = Fazf1-Fac3-offset3;
Mxf1 = Maxf1-Mac1-offset4;
Myf1 = Mayf1-Mac2-offset5;
Mzf1 = Mazf1-Mac3-offset6;

%-----------------------v=9---------------------------------%
alpha2 = alpha(v>7.5&v<9);
v2 = v(v>7.5&v<9);
rho2 = rho(v>7.5&v<9);
Fax2 = Fax(v>7.5&v<9);
Max2 = Max(v>7.5&v<9);
Fay2 = Fay(v>7.5&v<9);
May2 = May(v>7.5&v<9);
Faz2 = Faz(v>7.5&v<9);
Maz2 = Maz(v>7.5&v<9);
[alpha2, ialpha2, ~] = unique(alpha2);
v2 = v2(ialpha2);
rho2 = rho2(ialpha2);
Fax2 = Fax2(ialpha2);
Max2 = Max2(ialpha2);
Fay2 = Fay2(ialpha2);
May2 = May2(ialpha2);
Faz2 = Faz2(ialpha2);
Maz2 = Maz2(ialpha2);
vf2 = interp1(alpha2,v2,alphai,'nearest');
rhof2 = interp1(alpha2,rho2,alphai,'nearest');
Faxf2 = interp1(alpha2,Fax2,alphai,'nearest');
Fayf2 = interp1(alpha2,Fay2,alphai,'nearest');
Fazf2 = interp1(alpha2,Faz2,alphai,'nearest');

Maxf2 = interp1(alpha2,Max2,alphai,'nearest');
Mayf2 = interp1(alpha2,May2,alphai,'nearest');
Mazf2 = interp1(alpha2,Maz2,alphai,'nearest');

Fxf2 = Faxf2-Fac1-offset1;
Fyf2 = Fayf2-Fac2-offset2;
Fzf2 = Fazf2-Fac3-offset3;
Mxf2 = Maxf2-Mac1-offset4;
Myf2 = Mayf2-Mac2-offset5;
Mzf2 = Mazf2-Mac3-offset6;


%-----------------------v=12---------------------------------%
alpha3 = alpha(v>10.5&v<11.5);
v3 = v(v>10.5&v<11.5);
rho3 = rho(v>10.5&v<11.5);
Fax3 = Fax(v>10.5&v<11.5);
Max3 = Max(v>10.5&v<11.5);
Fay3 = Fay(v>10.5&v<11.5);
May3 = May(v>10.5&v<11.5);
Faz3 = Faz(v>10.5&v<11.5);
Maz3 = Maz(v>10.5&v<11.5);
[alpha3, ialpha3, ~] = unique(alpha3);
v3 = v3(ialpha3);
rho3 = rho3(ialpha3);
Fax3 = Fax3(ialpha3);
Max3 = Max3(ialpha3);
Fay3 = Fay3(ialpha3);
May3 = May3(ialpha3);
Faz3 = Faz3(ialpha3);
Maz3 = Maz3(ialpha3);
vf3 = interp1(alpha3,v3,alphai,'nearest');
rhof3 = interp1(alpha3,rho3,alphai,'nearest');
Faxf3 = interp1(alpha3,Fax3,alphai,'nearest');
Fayf3 = interp1(alpha3,Fay3,alphai,'nearest');
Fazf3 = interp1(alpha3,Faz3,alphai,'nearest');

Maxf3 = interp1(alpha3,Max3,alphai,'nearest');
Mayf3 = interp1(alpha3,May3,alphai,'nearest');
Mazf3 = interp1(alpha3,Maz3,alphai,'nearest');

Fxf3 = Faxf3-Fac1-offset1;
Fyf3 = Fayf3-Fac2-offset2;
Fzf3 = Fazf3-Fac3-offset3;
Mxf3 = Maxf3-Mac1-offset4;
Myf3 = Mayf3-Mac2-offset5;
Mzf3 = Mazf3-Mac3-offset6;
%-----------------------v=15---------------------------------%
alpha4 = alpha(v>13&v<14);
v4 = v(v>13&v<14);
rho4 = rho(v>13&v<14);
Fax4 = Fax(v>13&v<14);
Max4 = Max(v>13&v<14);
Fay4 = Fay(v>13&v<14);
May4 = May(v>13&v<14);
Faz4 = Faz(v>13&v<14);
Maz4= Maz(v>13&v<14);
[alpha4, ialpha4, ~] = unique(alpha4);
v4 = v4(ialpha4);
rho4 = rho4(ialpha4);
Fax4 = Fax4(ialpha4);
Max4 = Max4(ialpha4);
Fay4 = Fay4(ialpha4);
May4 = May4(ialpha4);
Faz4 = Faz4(ialpha4);
Maz4 = Maz4(ialpha4);
vf4 = interp1(alpha4,v4,alphai,'nearest');
rhof4 = interp1(alpha4,rho4,alphai,'nearest');
Faxf4 = interp1(alpha4,Fax4,alphai,'nearest');
Fayf4 = interp1(alpha4,Fay4,alphai,'nearest');
Fazf4 = interp1(alpha4,Faz4,alphai,'nearest');

Maxf4 = interp1(alpha4,Max4,alphai,'nearest');
Mayf4 = interp1(alpha4,May4,alphai,'nearest');
Mazf4 = interp1(alpha4,Maz4,alphai,'nearest');

Fxf4 = Faxf4-Fac1-offset1;
Fyf4 = Fayf4-Fac2-offset2;
Fzf4 = Fazf4-Fac3-offset3;
Mxf4 = Maxf4-Mac1-offset4;
Myf4 = Mayf4-Mac2-offset5;
Mzf4 = Mazf4-Mac3-offset6;
arad = deg2rad(alphai);
arad = [arad;arad;arad;arad];
alphai = [alphai;alphai;alphai;alphai];
Fxf = [Fxf1;Fxf2;Fxf3;Fxf4];
Mxf = [Mxf1;Mxf2;Mxf3;Mxf4];
Fyf = [Fyf1;Fyf2;Fyf3;Fyf4];
Myf = [Myf1;Myf2;Myf3;Myf4];
Fzf = [Fzf1;Fzf2;Fzf3;Fzf4];
Mzf = [Mzf1;Mzf2;Mzf3;Mzf4];
vf = [vf1;vf2;vf3;vf4];
rhof = [rhof1;rhof2;rhof3;rhof4];

% lift and drag

%for 70% throttle, L,D calculated above are not pure aerodynamic forces,
%including the components of thrust on the respective axis.
%for 0% throttle, there is no thrust. L, D are aerodynamic forces only
L = -sin(arad).*Fxf - cos(arad).*Fyf;
D = cos(arad).*Fxf - sin(arad).*Fyf;
M = Mzf;

% Aerodynamic coefficients

%for 0% throttle, there is no thrust. L, D are aerodynamic forces only
%aerodynamic coefficients are as follows
% CL =  L .*2 ./(rhof .* vf.^2 .*A);
% CD =  D .*2 ./(rhof .* vf.^2 .*A);
% CM = M .*2 ./(rhof .* vf.^2 .*A .*c);

for i = 1:length(alphai)
    if i<=3601
        j=i;
        L0(j) = L(i);
        D0(j) = D(i);
        M0(j) = M(i);
        else if i>3601&&i<=7202
               j=i-3601; 
        L2(j) = L(i);
        D2(j) = D(i);
        M2(j) = M(i);
            else if i>7202&&i<=10803
                    j=i-7202;
        L3(j) = L(i);
        D3(j) = D(i);
        M3(j) = M(i);
                else if i>10803&&i<=14404
                        j=i-10803;
        L4(j) = L(i);
        D4(j) = D(i);
        M4(j) = M(i);

                end
            end
        end
    end
end   

L0=L0';
L2=L2';
L3=L3';
L4=L4';
D0=D0';
D2=D2';
D3=D3';
D4=D4';
M0=M0';
M2=M2';
M3=M3';
M4=M4';
% for 0% throttle, plot aerodynamic coefficients; for 70% throttle plot forces.
fig_pos = [0.09 0.13 0.68 0.82];
h = figure(1);
ax1 = axes;
set(ax1,'position',fig_pos );
h_1 = scatter(ax1,alphai,L,5,vf,'filled');
ylim([-60,60]);
colormap(ax1,winter);%original data
ylabel('L'); xlabel('\alpha [deg]');
title(['Lift under ', str1 , ', ', str2]);
backColor = [1 1 1];
set(gca, 'color', backColor);
box on;grid on;hidden off;


h = figure(2);
ax3 = axes;
set(ax3,'position',fig_pos );
h_1 = scatter(ax3,alphai,D,5,vf,'filled');
ylim([-30,60]);%
colormap(ax3,winter);
ylabel('D'); xlabel('\alpha [deg]');
title(['Drag under ', str1 , ', ',str2]);
set(gca, 'color', backColor);
box on;grid on;hidden off;



h = figure(4);
ax5 = axes;
set(ax5,'position',fig_pos );
h_1 = scatter(ax5,alphai,M,5,vf,'filled');
ylim([-10,10]);
colormap(ax5,winter);
ylabel('M'); xlabel('\alpha [deg]');
title(['Mz under ', str1 , ', ',str2]);
set(gca, 'color', backColor);
box on; grid on; hidden off;


% colorar gets darker with the increase of V
cb1 = colorbar(ax1,'Position',[.80 .13 .04 .82]);
% cb2 = colorbar(ax2,'Position',[.88 .13 .04 .82]);
cb1.Label.String = 'V [m/s]';
cb3 = colorbar(ax3,'Position',[.80 .13 .04 .82]);
% cb4 = colorbar(ax4,'Position',[.88 .13 .04 .82]);
cb3.Label.String = 'V [m/s]';
cb5 = colorbar(ax5,'Position',[.80 .13 .04 .82]);
% cb6 = colorbar(ax6,'Position',[.88 .13 .04 .82]);
cb5.Label.String = 'V [m/s]';

switch no
    case 0
        return;
    case 1
        Lfiltered = Lf;
    case 2
        Lfiltered = Lf;
        Dfiltered = Df;
    case 3
        Lfiltered = Lf;
        Dfiltered = Df;
        Mfiltered = Mf;
    otherwise
        error('The number of output exceeds');
end

end